@@ -16,6 +16,7 @@ Auth = namedtuple("Auth", [
     "create_user",
     "update_user_email",
     "update_user_metadata",
+    "create_magic_link", "migrate_user_from_external_source", "create_org", "add_user_to_org"
 ])
 
 
@@ -46,4 +47,8 @@ def init_auth(auth_url: str, api_key: str, token_verification_metadata: TokenVer
         create_user=auth.create_user,
         update_user_email=auth.update_user_email,
         update_user_metadata=auth.update_user_metadata,
+        create_magic_link=auth.create_magic_link,
+        migrate_user_from_external_source=auth.migrate_user_from_external_source,
+        create_org=auth.create_org,
+        add_user_to_org=auth.add_user_to_org,
     )
